"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ExternalLinkNode_1 = require("./ExternalLinkNode");
const ImageNode_1 = require("./ImageNode");
exports.urlRegExp = /^(.*?)\[(?<href>https?:\/\/[^\s\]]+)(?<content>)\](.*)$/;
exports.leftUrlRegExp = /^(.*?)\[(?<href>https?:\/\/[^\s\]]+)\s+(?<content>[^\]]*[^\s])\](.*)$/;
exports.rightUrlRegExp = /^(.*?)\[(?<content>[^\]]*[^\s])\s+(?<href>https?:\/\/[^\s\]]+)\](.*)$/;
exports.isUrlMatch = (obj) => (obj && obj.groups && obj.groups.href);
const isUrl = (text) => (/^https?:\/\/[^\s\]]+$/.test(text));
const isImageUrl = (text) => (/^https?:\/\/[^\s\]]+\.(png|jpe?g|gif|svg)$/i.test(text) || isGyazoImageUrl(text));
const isGyazoImageUrl = (text) => (/^https?:\/\/([0-9a-z-]\.)?gyazo\.com\/[0-9a-f]{32}(\/raw)?$/.test(text));
exports.createUrlNode = (href, content = '') => {
    if (content === '')
        return isImageUrl(href) ? ImageNode_1.createImageNode(href, content) : ExternalLinkNode_1.createExternalLinkNode(href, content);
    if (content && !isUrl(content))
        return ExternalLinkNode_1.createExternalLinkNode(href, content);
    if (isGyazoImageUrl(content))
        return ImageNode_1.createImageNode(content, href);
    if (isGyazoImageUrl(href))
        return ImageNode_1.createImageNode(href, content);
    if (isImageUrl(content))
        return ImageNode_1.createImageNode(content, href);
    return ImageNode_1.createImageNode(href, content);
};
//# sourceMappingURL=index.js.map